import sys

PYTHON3 = sys.version_info >= (3,)

try:
    # Check if the patch to test Python without its peephole has been
    # applied
    PyCF_DISABLE_PEEPHOLE = 0x1000
    compile("1+1", "<ast>", "exec", PyCF_DISABLE_PEEPHOLE)
except ValueError:
    # No worry, the patch is optionnal, even for unit tests
    PyCF_DISABLE_PEEPHOLE = 0

if PYTHON3:
    BYTES_TYPE = bytes
    UNICODE_TYPE = str
    def u(text):
        return text
    def b(text):
        return text.encode('latin1')
else:
    BYTES_TYPE = str
    UNICODE_TYPE = unicode
    def u(text):
        return unicode(text, "unicode_escape")
    def b(text):
        return text
NATIVE_STR = str

STR_TYPES = (BYTES_TYPE, UNICODE_TYPE)
if PYTHON3:
    INT_TYPES = (int,)
else:
    INT_TYPES = (int, long)
FLOAT_TYPES = INT_TYPES + (float,)
COMPLEX_TYPES = INT_TYPES + (float, complex)

def check_unicode_subscript(config, text):
    if not isinstance(text, UNICODE_TYPE):
        return True
    if 'pythonenv' in config.features:
        return True
    if sys.version_info >= (3,3):
        return True
    # Don't optimize subscript on non-BMP strings because the
    # result is different on narrow and wide builds
    if sys.maxunicode == 0x10ffff:
        return all(ord(char) <= 0xffff for char in text)
    else:
        return all(not 0xd800 <= ord(char) <= 0xdfff for char in text)

try:
    import ast
except ImportError:
    from astoptimizer import ast_python27 as ast

