"""
Enable optimizations specific to the platform (ex: sys.platform) and the Python
version (ex: sys.hexversion).

WARNING: On Python < 2.7.3 and < 3.2.2, sys.platform can be 'linux2' or
'linux3' depending on the major version of the Linux kernel. Ensure that
your application uses sys.platform.startswith("linux").
"""

import os
import sys
import platform
from astoptimizer.config import check_noarg

def setup_config(config):
    config.constants.update({
        'os.name': os.name,
        'sys.byteorder': sys.byteorder,
        'sys.platform': sys.platform,
    })

    config.pure_functions['platform.system'] = (check_noarg, platform.system)
    if sys.platform in ('darwin', 'win32'):
        config.pure_functions['sys.getfilesystemencoding'] = (check_noarg, sys.getfilesystemencoding)

