"""
Enable optimizations specific to the Python version, command line
and environment variables.

Only enable these optimizations if you don't control the exact Python version,
command line arguments and environment variables. Don't copy the resulting .pyc
files to another host because the environment may be different. For example,
-Qnew command line option of Python 2.7 changes the division operator.
"""

import sys
import platform

def setup_config(config):
    # On Python 2, the optimizer enables optimization on a/b operator
    # when this feature is used, because the behaviour depends on the
    # -Q command line option

    config.constants.update({
        # depend on the Python command line option "-O"
        '__debug__': __debug__,
        # dependg on the Python version
        'sys.hexversion': sys.hexversion,
        'sys.version': sys.version,
    })
    if sys.version_info >= (3, 2):
        config.constants['sys.abiflags'] = sys.abiflags


